@@ -1005,7 +1005,7 @@ class NaroNet_dataset(torch.utils.data.Dataset):
         '''
     
         # Obtain Neigh-to-Pheno, and Area-to-Neigh heatmap.
-        for ClusteringTrheshold in [0,50,90]:
+        for ClusteringTrheshold in [0,90]:
             Area_to_Neighborhood_to_Phenotype(self,clusters,IndexAndClass,ClusteringTrheshold)
 
         # Obtain cell-types examples
